@@ -1,6 +1,3 @@
-#ifndef _CTYPES_H_
-#define _CTYPES_H_
-
 #ifdef  __cplusplus
 extern "C" {
 #endif
@@ -18,8 +15,6 @@ int rdf(int nbins, double rcut, double * g_r, int Npart1, int Npart2, int Nsteps
 }
 #endif
 
-#endif  /* _CTYPES_H_ */
-
 #define MAX_X_LIST 3
 #define MAX_L_LIST MAX_X_LIST*MAX_X_LIST*MAX_X_LIST
 
@@ -41,26 +36,27 @@ int get_nearests(double x1, double x2, double cell, double rcut){
         dx = dx-cell;
     }
     x_list_0=x_list_id;
-    x_list[x_list_id]=fabs(dx);
-    x_list_id++;
     while (dx < rcut){
         if (x_list_id-x_list_0 >= MAX_X_LIST){
+            printf ("dx: %f | ", dx);
+            printf("exit -1 (dx < rcut)\n");
             exit(-1);
         }
-        dx += cell;
         x_list[x_list_id]=fabs(dx);
         x_list_id++;
+        dx += cell;
     }   
 
     dx = x_list[x_list_0]-cell;
     while (dx > -rcut){
         if (x_list_id-x_list_0 >= MAX_X_LIST){
-            printf("exit -1 dx > -rcut");
+            printf ("dx: %f | ", dx);
+            printf("exit -1 (dx > -rcut)\n");
             exit(-1);
         }
-        dx -= cell;
         x_list[x_list_id]=fabs(dx);
         x_list_id++;
+        dx -= cell;
     }
     while(x_list_id-x_list_0 < MAX_X_LIST){
         x_list[x_list_id]=-1;
